@@ -1,4 +1,5 @@
 import operator
+import re
 from datetime import date, datetime, timedelta
 
 import django.forms as forms
@@ -16,12 +17,13 @@ from dynamic_preferences.forms import PreferenceForm
 from guardian.shortcuts import assign_perm, get_objects_for_user, get_users_with_perms, remove_perm
 from recurrence.forms import RecurrenceField
 
-from ephios.core import signup
+from ephios.core import event_type_preference_registry, signup
 from ephios.core.models import Event, EventType, LocalParticipation, Shift, UserProfile
-from ephios.core.registries import event_type_preference_registry
 from ephios.core.widgets import MultiUserProfileWidget
 from ephios.extra.permissions import get_groups_with_perms
-from ephios.extra.widgets import CustomDateInput, CustomTimeInput
+from ephios.extra.widgets import ColorInput, CustomDateInput, CustomTimeInput
+from ephios.modellogging.log import add_log_recorder, update_log
+from ephios.modellogging.recorders import InstanceActionType, PermissionLogRecorder
 
 
 class EventForm(forms.ModelForm):
@@ -97,7 +99,10 @@ class EventForm(forms.ModelForm):
 
     def save(self, commit=True):
         self.instance.type = self.eventtype
-        event = super().save(commit=commit)
+        event: Event = super().save(commit=commit)
+
+        add_log_recorder(event, PermissionLogRecorder("view_event", _("Visible for")))
+        add_log_recorder(event, PermissionLogRecorder("change_event", _("Responsibles")))
 
         # delete existing permissions
         # (better implement https://github.com/django-guardian/django-guardian/issues/654)
@@ -126,6 +131,8 @@ class EventForm(forms.ModelForm):
         # Assign view_event to responsible users  and to non-responsible users
         # that already have some sort of participation for the event
         # (-> they saw and interacted with it)
+        # We can't just do users that aren't included by group permissions,
+        # as they might get removed from that group.
         assign_perm(
             "view_event",
             UserProfile.objects.filter(
@@ -139,14 +146,15 @@ class EventForm(forms.ModelForm):
             event,
         )
 
+        update_log(event, InstanceActionType.CHANGE)
         return event
 
 
 class ShiftForm(forms.ModelForm):
-    date = forms.DateField(widget=CustomDateInput(format="%Y-%m-%d"))
-    meeting_time = forms.TimeField(widget=CustomTimeInput)
-    start_time = forms.TimeField(widget=CustomTimeInput)
-    end_time = forms.TimeField(widget=CustomTimeInput)
+    date = forms.DateField(widget=CustomDateInput(format="%Y-%m-%d"), label=_("Date"))
+    meeting_time = forms.TimeField(widget=CustomTimeInput, label=_("Meeting time"))
+    start_time = forms.TimeField(widget=CustomTimeInput, label=_("Start time"))
+    end_time = forms.TimeField(widget=CustomTimeInput, label=_("End time"))
 
     field_order = ["date", "meeting_time", "start_time", "end_time", "signup_method_slug"]
 
@@ -190,6 +198,7 @@ class EventDuplicationForm(forms.Form):
         help_text=_(
             "This date will be used as the start date for recurring events that you create below, e.g. daily events will be created from this date onwards."
         ),
+        label=_("Start date"),
     )
     recurrence = RecurrenceField(required=False)
 
@@ -197,23 +206,39 @@ class EventDuplicationForm(forms.Form):
 class EventTypeForm(forms.ModelForm):
     class Meta:
         model = EventType
-        fields = ["title", "can_grant_qualification"]
+        fields = ["title", "can_grant_qualification", "color"]
+        widgets = {"color": ColorInput()}
+
+    def clean_color(self):
+        regex = re.compile(r"#[a-fA-F\d]{6}")
+        if not regex.match(self.cleaned_data["color"]):
+            raise ValidationError(_("You need to enter a valid color"))
+        return self.cleaned_data["color"]
 
 
 class EventTypePreferenceForm(PreferenceForm):
     registry = event_type_preference_registry
 
 
-class BaseEventPluginForm(forms.Form):
+class BaseEventPluginFormMixin:
     @property
     def heading(self):
         raise NotImplementedError
 
     def render(self):
+        try:
+            self.helper.form_tag = False
+        except AttributeError:
+            self.helper = FormHelper(self)
+            self.helper.form_tag = False
         return render_to_string("core/fragments/event_plugin_form.html", context={"form": self})
 
-    def save(self):
-        pass
+    def is_function_active(self):
+        """
+        When building forms for additional features, return whether that feature is enabled for the forms event instance.
+        With the default template, if this is True, the collapse is expanded on page load.
+        """
+        return False
 
 
 class EventNotificationForm(forms.Form):
@@ -229,7 +254,7 @@ class EventNotificationForm(forms.Form):
         widget=forms.RadioSelect,
         label=False,
     )
-    mail_content = forms.CharField(required=False, widget=forms.Textarea)
+    mail_content = forms.CharField(required=False, widget=forms.Textarea, label=_("Mail content"))
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
