@@ -21,11 +21,58 @@ from guardian.shortcuts import assign_perm, get_objects_for_group, remove_perm
 
 from ephios.core.consequences import WorkingHoursConsequenceHandler
 from ephios.core.models import QualificationGrant, UserProfile
-from ephios.core.notifications.backends import enabled_notification_backends
-from ephios.core.notifications.types import enabled_notification_types
+from ephios.core.services.notifications.backends import enabled_notification_backends
+from ephios.core.services.notifications.types import enabled_notification_types
 from ephios.core.widgets import MultiUserProfileWidget
 from ephios.extra.permissions import PermissionField, PermissionFormMixin
 from ephios.extra.widgets import CustomDateInput
+from ephios.modellogging.log import add_log_recorder
+from ephios.modellogging.recorders import DerivedFieldsLogRecorder
+
+MANAGEMENT_PERMISSIONS = [
+    "auth.add_group",
+    "auth.change_group",
+    "auth.delete_group",
+    "auth.view_group",
+    "core.add_userprofile",
+    "core.change_userprofile",
+    "core.delete_userprofile",
+    "core.view_userprofile",
+    "core.view_event",
+    "core.add_event",
+    "core.change_event",
+    "core.delete_event",
+    "core.view_eventtype",
+    "core.add_eventtype",
+    "core.change_eventtype",
+    "core.delete_eventtype",
+    "core.view_qualification",
+    "core.add_qualification",
+    "core.change_qualification",
+    "core.delete_qualification",
+    "modellogging.view_logentry",
+]
+
+
+def get_group_permission_log_fields(group):
+    # This lives here because it is closely related to the fields on GroupForm below
+    if not group.pk:
+        return {}
+    perms = set(group.permissions.values_list("codename", flat=True))
+
+    return {
+        _("Can view past events"): "view_past_event" in perms,
+        _("Can add events"): "add_event" in perms,
+        _("Can edit users"): "change_userprofile" in perms,
+        _("Can manage ephios"): "change_group" in perms,
+        # force evaluation of querysets
+        _("Can publish events for groups"): set(
+            get_objects_for_group(group, "publish_event_for_group", klass=Group)
+        ),
+        _("Can decide working hours for groups"): set(
+            get_objects_for_group(group, "decide_workinghours_for_group", klass=Group)
+        ),
+    }
 
 
 class GroupForm(PermissionFormMixin, ModelForm):
@@ -73,28 +120,7 @@ class GroupForm(PermissionFormMixin, ModelForm):
         help_text=_(
             "If checked, users in this group can manage users, groups, all group memberships, eventtypes and qualifications"
         ),
-        permissions=[
-            "auth.add_group",
-            "auth.change_group",
-            "auth.delete_group",
-            "auth.view_group",
-            "core.add_userprofile",
-            "core.change_userprofile",
-            "core.delete_userprofile",
-            "core.view_userprofile",
-            "core.view_event",
-            "core.add_event",
-            "core.change_event",
-            "core.delete_event",
-            "core.view_eventtype",
-            "core.add_eventtype",
-            "core.change_eventtype",
-            "core.delete_eventtype",
-            "core.view_qualification",
-            "core.add_qualification",
-            "core.change_qualification",
-            "core.delete_qualification",
-        ],
+        permissions=MANAGEMENT_PERMISSIONS,
         required=False,
     )
 
@@ -143,12 +169,13 @@ class GroupForm(PermissionFormMixin, ModelForm):
         )
 
     def save(self, commit=True):
+        add_log_recorder(self.instance, DerivedFieldsLogRecorder(get_group_permission_log_fields))
         group = super().save(commit)
 
         group.user_set.set(self.cleaned_data["users"])
 
         remove_perm("publish_event_for_group", group, Group.objects.all())
-        if self.cleaned_data["is_planning_group"]:
+        if group.permissions.filter(codename="add_event").exists():
             assign_perm(
                 "publish_event_for_group", group, self.cleaned_data["publish_event_for_group"]
             )
@@ -161,6 +188,7 @@ class GroupForm(PermissionFormMixin, ModelForm):
                 self.cleaned_data["decide_workinghours_for_group"],
             )
 
+        group.save()  # logging
         return group
 
 
