@@ -275,6 +275,8 @@ def check_conflicting_shifts(method, participant):
 
 
 class BaseSignupMethod:
+    # pylint: disable=too-many-public-methods
+
     @property
     def slug(self):
         raise NotImplementedError()
@@ -283,9 +285,23 @@ class BaseSignupMethod:
     def verbose_name(self):
         raise NotImplementedError()
 
+    @property
+    def disposition_participation_form_class(self):
+        """
+        This form will be used for participations in disposition.
+        Set to None if you don't want to support the default disposition.
+        """
+        return BaseDispositionParticipationForm
+
+    @property
+    def configuration_form_class(self):
+        return forms.Form
+
+    @property
+    def signup_view_class(self):
+        return BaseSignupView
+
     description = """"""
-    signup_view_class = BaseSignupView
-    configuration_form_class = forms.Form
 
     # use _ == gettext_lazy!
     registration_button_text = _("Sign up")
@@ -294,11 +310,6 @@ class BaseSignupMethod:
     decline_success_message = _("You have successfully declined {shift}.")
     decline_error_message = _("Declining failed: {error}")
 
-    """
-    This form will be used for participations in disposition.
-    Set to None if you don't want to support the default disposition.
-    """
-    disposition_participation_form_class = BaseDispositionParticipationForm
     uses_requested_state = True
 
     def __init__(self, shift):
@@ -364,7 +375,7 @@ class BaseSignupMethod:
         Creates and/or configures a participation object for a given participant and sends out notifications.
         Passes the participation and kwargs to configure_participation to do configuration specific to the signup method
         """
-        from ephios.core.notifications.types import ResponsibleParticipationRequested
+        from ephios.core.services.notifications.types import ResponsibleParticipationRequested
 
         if errors := self.get_signup_errors(participant):
             raise ParticipationError(errors)
