@@ -26,7 +26,10 @@ from ephios.core.forms.users import (
     UserProfileForm,
 )
 from ephios.core.models import QualificationGrant, UserProfile
-from ephios.core.notifications.types import NewProfileNotification, ProfileUpdateNotification
+from ephios.core.services.notifications.types import (
+    NewProfileNotification,
+    ProfileUpdateNotification,
+)
 from ephios.extra.mixins import CustomPermissionRequiredMixin
 
 
@@ -54,7 +57,7 @@ class UserProfileListView(CustomPermissionRequiredMixin, ListView):
                     to_attr=f"qualifications_for_category_{category.pk}",
                 )
             )
-        return qs
+        return qs.order_by("last_name", "first_name")
 
 
 class UserProfileCreateView(CustomPermissionRequiredMixin, TemplateView):
